A theme for [github.com/hit9/rux.git](http://github.com/hit9/rux.git)

How to use

```bash
cd path/to/myblog
```

clone it or add it a submodule of your blog's repo.

```bash
git clone git://github.com/hit9/rux-theme-default.git default
```

or

```bash
git submodule add git://github.com/hit9/rux-theme-default.git default
```

set `theme` to `default` in your `config.toml`
